# Changelog

[PyPI History][1]

[1]: https://pypi.org/project/demisto-py/#history

## 2.0.1
Improved the changelog and documentation.

## 2.0.0
Initial release of new Swagger based API for Demisto Server 4.5.0 and up.

## 1.0.0
Deprecated: demisto-py 1.x is officially in maintenance-mode only and can be obtained at: https://github.com/demisto/demisto-py/releases .
